@@ -13,7 +13,7 @@
  * Copyright (c) 2009-2013,
  * University of Oregon, Eugene, USA
  *
- * Copyright (c) 2009-2013, 2015,
+ * Copyright (c) 2009-2013, 2015, 2025,
  * Forschungszentrum Juelich GmbH, Germany
  *
  * Copyright (c) 2009-2013,
@@ -139,11 +139,10 @@ set_disabled( const string& constructs )
 {
     typedef std::pair<char*, bool> dir_and_inner_t;
 
-    char str[ constructs.length() + 1 ];
-    std::strcpy( &str[ 0 ], constructs.c_str() );
+    char* str = strdup( constructs.c_str() );
 
     std::vector<char*> paradigms;
-    char*              paradigm = strtok( &str[ 0 ], "+" );
+    char*              paradigm = strtok( str, "+" );
 
     while ( paradigm != NULL )
     {
@@ -180,6 +179,7 @@ set_disabled( const string& constructs )
                 else
                 {
                     cerr << "Error, unknown identifier " <<  inner << std::endl;
+                    free( str );
                     return false;
                 }
             }
@@ -189,6 +189,7 @@ set_disabled( const string& constructs )
         {
             if ( !DisableParadigmDirectiveOrGroup( paradigm, "", false ) )
             {
+                free( str );
                 return false;
             }
         }
@@ -198,12 +199,14 @@ set_disabled( const string& constructs )
             {
                 if ( !DisableParadigmDirectiveOrGroup( paradigm, it->first, it->second ) )
                 {
+                    free( str );
                     return false;
                 }
             }
         }
     }
 
+    free( str );
     return true;
 }
 
