@@ -13,7 +13,7 @@
  * Copyright (c) 2009-2013,
  * University of Oregon, Eugene, USA
  *
- * Copyright (c) 2009-2013, 2014, 2016,
+ * Copyright (c) 2009-2013, 2014, 2016, 2025,
  * Forschungszentrum Juelich GmbH, Germany
  *
  * Copyright (c) 2009-2013,
@@ -56,8 +56,6 @@ using std::getline;
 using std::transform;
 using std::sort;
 using std::min;
-#include <functional>
-using std::greater;
 #include <cstring>
 using std::strlen;
 using std::remove_if;
@@ -66,7 +64,7 @@ using std::remove_if;
 #include "opari2_parser_f.h"
 #include "opari2_directive_manager.h"
 
-struct fo_tolower : public std::unary_function<int, int>
+struct fo_tolower
 {
     int
     operator()( int x ) const
@@ -171,7 +169,7 @@ OPARI2_FortranParser::is_sub_unit_header( void )
     //Check if we enter a program block
     inProgram = inProgram || ( sline.find( "program" ) == 0 );
     //Check if we enter a module block
-    inModule = !inProgram && ( inModule || ( sline.find( "module" ) == 0 ) );
+    inModule = !inProgram && ( inModule || ( sline.find( "module" ) == 0 ) && sline.find( "subroutine" ) == string::npos );
     //Check if we enter an interface block
     inInterface = inModule && ( inInterface || ( sline.find( "interface" ) == 0 ) || ( sline.find( "abstractinterface" ) == 0 ) );
     //Check if we enter a contains block
